@@ -1,5 +1,3 @@
-context("test functioning of algorithm, type 1")
-
 prefix <- tempdir()
 # prefix <- "tests/testthat/" # nolint
 
@@ -19,7 +17,7 @@ test_that(
 
     local_edition(3)
 
-    suppressWarnings(future::plan("multiprocess"))
+    suppressWarnings(future::plan("multisession"))
 
     #"skip_on_cran()
 
@@ -191,7 +189,7 @@ test_that(
     )
 
     # hyperbolic correction
-    rv$choices_list <- rv$reg_stats[, c("Name"), with = F
+    rv$choices_list <- rv$reg_stats[, c("Name"), with = FALSE
     ][
       , ("better_model") := 0
     ]
@@ -273,7 +271,7 @@ test_that(
     )
 
     # cubic correction
-    rv$choices_list <- rv$reg_stats[, c("Name"), with = F
+    rv$choices_list <- rv$reg_stats[, c("Name"), with = FALSE
     ][
       , ("better_model") := 1
     ]
